@@ -1,16 +1,19 @@
-from __future__ import absolute_import
-from __future__ import print_function
+"""Module provider for Easyname DNS"""
+from __future__ import absolute_import, print_function
 import logging
-import sys
 
-from requests import Session, Response
-from .base import Provider as BaseProvider
+from requests import Response, Session
 
-logger = logging.getLogger(__name__)
+from lexicon.providers.base import Provider as BaseProvider
+
+
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = ['easyname.eu']
 
-def ProviderParser(subparser):
+
+def provider_parser(subparser):
+    """Configure provider parser for Easyname DNS"""
     subparser.description = """A provider for Easyname DNS."""
     subparser.add_argument(
         '--auth-username',
@@ -22,7 +25,6 @@ def ProviderParser(subparser):
     )
 
 
-
 class Provider(BaseProvider):
     """
         easyname provider
@@ -34,18 +36,17 @@ class Provider(BaseProvider):
         'overview': 'https://my.easyname.com/hosting/view-user.php',
         'dns': 'https://my.easyname.com/domains/settings/dns.php?domain={}',
         'dns_create_entry': 'https://my.easyname.com/domains/settings/form.php?domain={}',
-        'dns_delete_entry': 'https://my.easyname.com/domains/settings/delete_record.php?domain={}&confirm=1&id={}'
+        'dns_delete_entry':
+            'https://my.easyname.com/domains/settings/delete_record.php?domain={}&confirm=1&id={}'
     }
 
-
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.session = Session()
         self.domain_id = None
         self._records = None
 
-
-    def authenticate(self):
+    def _authenticate(self):
         """
         Authenticates against Easyname website and try to find out the domain
         id.
@@ -64,34 +65,36 @@ class Provider(BaseProvider):
 
         domain_text_element = self._get_domain_text_of_authoritative_zone()
         self.domain_id = self._get_domain_id(domain_text_element)
-        logger.debug('Easyname domain ID: {}'.format(self.domain_id))
+        LOGGER.debug('Easyname domain ID: %s', self.domain_id)
 
         return True
 
+    def _create_record(self, rtype, name, content):
+        return self._create_record_internal(rtype=rtype, name=name, content=content)
 
-    def create_record(self, type, name, content, id=None):
+    def _create_record_internal(self, rtype, name, content, identifier=None):
         """
         Create a new DNS entry in the domain zone if it does not already exist.
 
         Args:
-          type (str): The DNS type (e.g. A, TXT, MX, etc) of the new entry.
+          rtype (str): The DNS type (e.g. A, TXT, MX, etc) of the new entry.
           name (str): The name of the new DNS entry, e.g the domain for which a
                       MX entry shall be valid.
           content (str): The content of the new DNS entry, e.g. the mail server
                          hostname for a MX entry.
-          [id] (str): The easyname id of a DNS entry. Use to overwrite an
+          [identifier] (str): The easyname id of a DNS entry. Use to overwrite an
                     existing entry.
 
         Returns:
           bool: True if the record was created successfully, False otherwise.
         """
         name = self._relative_name(name) if name is not None else name
-        logger.debug('Creating record with name {}'.format(name))
-        if self._is_duplicate_record(type, name, content):
+        LOGGER.debug('Creating record with name %s', name)
+        if self._is_duplicate_record(rtype, name, content):
             return True
 
-        data = self._get_post_data_to_create_dns_entry(type, name, content, id)
-        logger.debug('Create DNS data: {}'.format(data))
+        data = self._get_post_data_to_create_dns_entry(rtype, name, content, identifier)
+        LOGGER.debug('Create DNS data: %s', data)
         create_response = self.session.post(
             self.URLS['dns_create_entry'].format(self.domain_id),
             data=data
@@ -100,24 +103,23 @@ class Provider(BaseProvider):
         self._log('Create DNS entry', create_response)
 
         # Pull a list of records and check for ours
-        was_success = len(self.list_records(type, name, content)) > 0
+        was_success = len(self._list_records(rtype, name, content)) > 0
         if was_success:
-            msg = 'Successfully added record {}'
+            msg = 'Successfully added record %s'
         else:
-            msg = 'Failed to add record {}'
+            msg = 'Failed to add record %s'
 
-        logger.info(msg.format(name))
+        LOGGER.info(msg, name)
         return was_success
 
-
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         """
         Delete one or more DNS entries in the domain zone that match the given
         criteria.
 
         Args:
           [identifier] (str): An ID to match against DNS entry easyname IDs.
-          [type] (str): A DNS type (e.g. A, TXT, MX, etc) to match against DNS
+          [rtype] (str): A DNS rtype (e.g. A, TXT, MX, etc) to match against DNS
                       entry types.
           [name] (str): A name to match against DNS entry names.
           [content] (str): A content to match against a DNS entry contents.
@@ -127,9 +129,9 @@ class Provider(BaseProvider):
                 otherwise.
         """
         success_url = self.URLS['dns'].format(self.domain_id)
-        record_ids = self._get_matching_dns_entry_ids(identifier, type,
+        record_ids = self._get_matching_dns_entry_ids(identifier, rtype,
                                                       name, content)
-        logger.debug('Record IDs to delete: {}'.format(record_ids))
+        LOGGER.debug('Record IDs to delete: %s', record_ids)
 
         success = True
         for rec_id in record_ids:
@@ -141,15 +143,14 @@ class Provider(BaseProvider):
 
         return success
 
-
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         """
         Update a DNS entry identified by identifier or name in the domain zone.
         Any non given argument will leave the current value of the DNS entry.
 
         Args:
           identifier (str): The easyname id of the DNS entry to update.
-          [type] (str): The DNS type (e.g. A, TXT, MX, etc) of the new entry.
+          [rtype] (str): The DNS rtype (e.g. A, TXT, MX, etc) of the new entry.
           [name] (str): The name of the new DNS entry, e.g the domain for which
                         a MX entry shall be valid.
           [content] (str): The content of the new DNS entry, e.g. the mail
@@ -163,39 +164,38 @@ class Provider(BaseProvider):
         """
         if identifier is not None:
             identifier = int(identifier)
-            records = self.list_records(id=identifier)
+            records = self._list_records_internal(identifier=identifier)
         else:
-            records = self.list_records(name=name, type=type)
-        logger.debug('Records to update ({}): {}'.format(
-                     len(records), records))
-        assert len(records) > 0, 'No record found to update'
+            records = self._list_records_internal(name=name, rtype=rtype)
+        LOGGER.debug('Records to update (%d): %s', len(records), records)
+        assert records, 'No record found to update'
         success = True
 
         for record in records:
             name = name if name is not None else record['name']
-            type = type if type is not None else record['type']
+            rtype = rtype if rtype is not None else record['type']
             content = content if content is not None \
-                                        else record['content']
-            success = success and self.create_record(type,
-                                                     name,
-                                                     content,
-                                                     record['id'])
+                else record['content']
+            success = success and self._create_record_internal(
+                rtype, name, content, record['id'])
         return success
 
+    def _list_records(self, rtype=None, name=None, content=None):
+        return self._list_records_internal(rtype=rtype, name=name, content=content)
 
-    def list_records(self, type=None, name=None, content=None, id=None):
+    def _list_records_internal(self, rtype=None, name=None, content=None, identifier=None):
         """
         Filter and list DNS entries of domain zone on Easyname.
         Easyname shows each entry in a HTML table row and each attribute on a
         table column.
 
         Args:
-          [type] (str): Filter by DNS type (e.g. A, TXT, MX, etc)
+          [rtype] (str): Filter by DNS rtype (e.g. A, TXT, MX, etc)
           [name] (str): Filter by the name of the DNS entry, e.g the domain for
                       which a MX entry shall be valid.
           [content] (str): Filter by the content of the DNS entry, e.g. the
                            mail server hostname for a MX entry.
-          [id] (str): Filter by the easyname id of the DNS entry.
+          [identifier] (str): Filter by the easyname id of the DNS entry.
 
         Returns:
           list: A list of DNS entries. A DNS entry is an object with DNS
@@ -210,14 +210,15 @@ class Provider(BaseProvider):
             records = []
             rows = self._get_dns_entry_trs()
 
-            for no, row in enumerate(rows):
+            for index, row in enumerate(rows):
                 self._log('DNS list entry', row)
                 try:
                     rec = {}
                     if row.has_attr('ondblclick'):
-                        rec['id'] = int(row['ondblclick'].split('id=')[1].split("'")[0])
+                        rec['id'] = int(row['ondblclick'].split(
+                            'id=')[1].split("'")[0])
                     else:
-                        rec['id'] = -no
+                        rec['id'] = -index
 
                     columns = row.find_all('td')
                     rec['name'] = (columns[0].string or '').strip()
@@ -226,27 +227,25 @@ class Provider(BaseProvider):
                     rec['priority'] = (columns[3].string or '').strip()
                     rec['ttl'] = (columns[4].string or '').strip()
 
-                    if len(rec['priority']) > 0:
+                    if rec['priority']:
                         rec['priority'] = int(rec['priority'])
 
-                    if len(rec['ttl']) > 0:
+                    if rec['ttl']:
                         rec['ttl'] = int(rec['ttl'])
-                except Exception as e:
-                    errmsg = 'Cannot parse DNS entry ({}).'.format(e)
-                    logger.warning(errmsg)
+                except Exception as error:
+                    errmsg = 'Cannot parse DNS entry ({}).'.format(error)
+                    LOGGER.warning(errmsg)
                     raise AssertionError(errmsg)
                 records.append(rec)
             self._records = records
 
-        records = self._filter_records(self._records, type, name, content, id)
-        logger.debug('Final records ({}): {}'.format(len(records), records))
+        records = self._filter_records(self._records, rtype, name, content, identifier)
+        LOGGER.debug('Final records (%d): %s', len(records), records)
         return records
 
-
-    def _request(self, action='GET',  url='/', data=None, query_params=None):
+    def _request(self, action='GET', url='/', data=None, query_params=None):
         pass
 
-
     def _invalidate_records_cache(self):
         """
         Invalidate DNS entries cache such that list_records will do a new
@@ -254,24 +253,22 @@ class Provider(BaseProvider):
         """
         self._records = None
 
-
-    def _get_post_data_to_create_dns_entry(self, type, name, content, id=None):
+    def _get_post_data_to_create_dns_entry(self, rtype, name, content, identifier=None):
         """
         Build and return the post date that is needed to create a DNS entry.
         """
-        is_update = id is not None
+        is_update = identifier is not None
         if is_update:
-            records = self.list_records(id=id)
+            records = self._list_records_internal(identifier=identifier)
             assert len(records) == 1, 'ID is not unique or does not exist'
             record = records[0]
-            logger.debug('Create post data to update record: {}'.\
-                         format(record))
+            LOGGER.debug('Create post data to update record: %s', record)
 
-        data={
-            'id': str(id) if is_update else '',
+        data = {
+            'id': str(identifier) if is_update else '',
             'action': 'save',
             'name': name,
-            'type': type,
+            'type': rtype,
             'content': content,
             'prio': str(record['priority']) if is_update else '10',
             'ttl': str(record['ttl']) if is_update else '360',
@@ -287,29 +284,25 @@ class Provider(BaseProvider):
 
         return data
 
-
-    def _is_duplicate_record(self, type, name, content):
+    def _is_duplicate_record(self, rtype, name, content):
         """Check if DNS entry already exists."""
-        records = self.list_records(type, name, content)
+        records = self._list_records(rtype, name, content)
         is_duplicate = len(records) >= 1
         if is_duplicate:
-            logger.info('Duplicate record {} {} {}, NOOP'.\
-                        format(type, name, content))
+            LOGGER.info('Duplicate record %s %s %s, NOOP', rtype, name, content)
         return is_duplicate
 
-
-    def _get_matching_dns_entry_ids(self, identifier=None, type=None,
+    def _get_matching_dns_entry_ids(self, identifier=None, rtype=None,
                                     name=None, content=None):
         """Return a list of DNS entries that match the given criteria."""
         record_ids = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             record_ids = [record['id'] for record in records]
         else:
             record_ids.append(identifier)
         return record_ids
 
-
     def _get_dns_entry_trs(self):
         """
         Return the TR elements holding the DNS entries.
@@ -319,7 +312,7 @@ class Provider(BaseProvider):
             self.URLS['dns'].format(self.domain_id))
         self._log('DNS list', dns_list_response)
         assert dns_list_response.status_code == 200, \
-               'Could not load DNS entries.'
+            'Could not load DNS entries.'
 
         html = BeautifulSoup(dns_list_response.content, 'html.parser')
         self._log('DNS list', html)
@@ -332,45 +325,39 @@ class Provider(BaseProvider):
             return elm.name.lower() == 'tr' and (has_class or has_ondblclick)
 
         rows = dns_table.findAll(_is_zone_tr)
-        assert rows is not None and len(rows) > 0, \
-               'Could not find any DNS entries'
+        assert rows is not None and rows, 'Could not find any DNS entries'
         return rows
 
-
-    def _filter_records(self, records, type=None, name=None, content=None, id=None):
+    def _filter_records(self, records, rtype=None, name=None, content=None, identifier=None):  # pylint: disable=too-many-arguments,no-self-use
         """
         Filter dns entries based on type, name or content.
         """
-        if len(records) < 1: return records
-        if id is not None:
-            logger.debug('Filtering {} records by id: {}'.\
-                         format(len(records), id))
-            records = [record for record in records if record['id'] == id]
-        if type is not None:
-            logger.debug('Filtering {} records by type: {}'.\
-                         format(len(records), type))
-            records = [record for record in records if record['type'] == type]
+        if not records:
+            return []
+        if identifier is not None:
+            LOGGER.debug('Filtering %d records by id: %s', len(records), identifier)
+            records = [record for record in records if record['id'] == identifier]
+        if rtype is not None:
+            LOGGER.debug('Filtering %d records by type: %s', len(records), rtype)
+            records = [record for record in records if record['type'] == rtype]
         if name is not None:
-            logger.debug('Filtering {} records by name: {}'.\
-                         format(len(records), name))
+            LOGGER.debug('Filtering %d records by name: %s', len(records), name)
             if name.endswith('.'):
                 name = name[:-1]
-            records = [record for record in records if name == record['name'] ]
+            records = [record for record in records if name == record['name']]
         if content is not None:
-            logger.debug('Filtering {} records by content: {}'.\
-                         format(len(records), content.lower()))
+            LOGGER.debug('Filtering %d records by content: %s', len(records), content.lower())
             records = [record for record in records if
                        record['content'].lower() == content.lower()]
         return records
 
-
     def _get_csrf_token(self):
         """Return the CSRF Token of easyname login form."""
         from bs4 import BeautifulSoup
         home_response = self.session.get(self.URLS['login'])
         self._log('Home', home_response)
         assert home_response.status_code == 200, \
-               'Could not load Easyname login page.'
+            'Could not load Easyname login page.'
 
         html = BeautifulSoup(home_response.content, 'html.parser')
         self._log('Home', html)
@@ -378,24 +365,22 @@ class Provider(BaseProvider):
         assert csrf_token_field is not None, 'Could not find login token.'
         return csrf_token_field['value']
 
-
     def _login(self, csrf_token):
         """Attempt to login session on easyname."""
         login_response = self.session.post(
-           self.URLS['login'],
+            self.URLS['login'],
             data={
-                'username':     self._get_provider_option('auth_username') or '',
-                'password':     self._get_provider_option('auth_password') or '',
-                'submit':       '',
-                'loginxtoken':  csrf_token,
+                'username': self._get_provider_option('auth_username') or '',
+                'password': self._get_provider_option('auth_password') or '',
+                'submit': '',
+                'loginxtoken': csrf_token,
             }
         )
         self._log('Login', login_response)
         assert login_response.status_code == 200, \
-               'Could not login due to a network error.'
+            'Could not login due to a network error.'
         assert login_response.url == self.URLS['overview'], \
-               'Easyname login failed, bad EASYNAME_USER or EASYNAME_PASS.'
-
+            'Easyname login failed, bad EASYNAME_USER or EASYNAME_PASS.'
 
     def _get_domain_text_of_authoritative_zone(self):
         """Get the authoritative name zone."""
@@ -404,7 +389,7 @@ class Provider(BaseProvider):
         zones_response = self.session.get(self.URLS['domain_list'])
         self._log('Zone', zones_response)
         assert zones_response.status_code == 200, \
-               'Could not retrieve domain list due to a network error.'
+            'Could not retrieve domain list due to a network error.'
 
         html = BeautifulSoup(zones_response.content, 'html.parser')
         self._log('Zone', html)
@@ -420,10 +405,10 @@ class Provider(BaseProvider):
         subdomains = domain.split('.')
         while True:
             domain = '.'.join(subdomains)
-            logger.debug('Check if {} has own zone'.format(domain))
+            LOGGER.debug('Check if %s has own zone', domain)
             domain_text = domain_table.find(string=domain)
             if domain_text is not None or len(subdomains) < 3:
-                break;
+                break
             subdomains.pop(0)
 
         # Update domain to equal the zone's domain. This is important if we are
@@ -432,34 +417,30 @@ class Provider(BaseProvider):
         # away.
         self.domain = domain
         assert domain_text is not None, \
-               'The domain does not exist on Easyname.'
+            'The domain does not exist on Easyname.'
         return domain_text
 
-
-    def _get_domain_id(self, domain_text_element):
+    def _get_domain_id(self, domain_text_element):  # pylint: disable=no-self-use
         """Return the easyname id of the domain."""
         try:
             # Hierarchy: TR > TD > SPAN > Domain Text
-            tr = domain_text_element.parent.parent.parent
-            td = tr.find('td', {'class': 'td_2'})
-            link = td.find('a')['href']
-            domain_id = link.rsplit('/',1)[-1]
+            tr_anchor = domain_text_element.parent.parent.parent
+            td_anchor = tr_anchor.find('td', {'class': 'td_2'})
+            link = td_anchor.find('a')['href']
+            domain_id = link.rsplit('/', 1)[-1]
             return domain_id
-        except Exception as e:
+        except Exception as error:
             errmsg = ('Cannot get the domain id even though the domain seems '
-                      'to exist ({}).'.format(e))
-            logger.warning(errmsg)
+                      'to exist (%s).', error)
+            LOGGER.warning(errmsg)
             raise AssertionError(errmsg)
 
-
-    def _log(self, name, element):
+    def _log(self, name, element):  # pylint: disable=no-self-use
         """
         Log Response and Tag elements. Do nothing if elements is none of them.
         """
         from bs4 import BeautifulSoup, Tag
         if isinstance(element, Response):
-            logger.debug('{} response: URL={} Code={}'.format(name,
-                         element.url, element.status_code))
-
-        elif isinstance(element, Tag) or isinstance(element, BeautifulSoup):
-            logger.debug('{} HTML:\n{}'.format(name, element))
\ No newline at end of file
+            LOGGER.debug('%s response: URL=%s Code=%s', name, element.url, element.status_code)
+        elif isinstance(element, (BeautifulSoup, Tag)):
+            LOGGER.debug('%s HTML:\n%s', name, element)
